@@ -7,12 +7,15 @@
 #ifndef SVGBROWSEREXTENSION_H
 #define SVGBROWSEREXTENSION_H
 
+// Qt
+#include <QtGlobal>
+
 // KF
-#include <KParts/BrowserExtension>
+#include <KParts/NavigationExtension>
 
 class SvgPart;
 
-class SvgBrowserExtension : public KParts::BrowserExtension
+class SvgBrowserExtension : public KParts::NavigationExtension
 {
     Q_OBJECT
 
